![ZCS Azzurro API image](https://github.com/AlePerla/zcs_azzurro_api/blob/main/icon.png?raw=true "ZCS Azzurro API logo")
# ZCS Azzurro client for Python
The unofficial python client for ZCS Azzurro API.

# Instructions
Access rights and credentials has to be asked to ZCS Azzurro support. 
The maintainer of this package does not manage access, 
which is in total control of the ZCS Azzurro APIs developers.

# Disclaimer
This package is not managed by the developer of the APIs and comes with no warranty about the functioning or the timing.
It is not guaranteed also the full implementation of all the functions of the APIs itself.
The package could be discontinued at any time and it might be outdated with the APIs, 
though it will be updated as much as possible.
You can use it under license conditions and under your responsibility.

Keep this on going >
<a href="https://paypal.me/aleperla13" target="_blank"><img src="https://www.paypalobjects.com/webstatic/mktg/logo/pp_cc_mark_37x23.jpg" border="0" alt="PayPal Logo" style="height: auto !important;width: auto !important;">Support</a>